:mod:`oujago.nlp.segment`
=========================

.. automodule:: oujago.nlp.segment

.. autosummary::

    BaseSegment
    LTPSeg
    JiebaSeg
    MoranSeg
    seg
    set_seg_mode
    get_seg_mode


Detailed Description
--------------------


.. autoclass:: BaseSegment
    :members:


.. autoclass:: LTPSeg
    :members:

.. autoclass:: JiebaSeg
    :members:

.. autoclass:: MoranSeg
    :members:

.. autofunction:: seg
.. autofunction:: set_seg_mode
.. autofunction:: get_seg_mode
